@@ -5,7 +5,7 @@ import os
 import pathlib
 from pathlib import Path
 
-__version__ = "0.1.27"
+__version__ = "0.1.30"
 
 #@title Functions Json decode dict
 def povRequestDecoder(povReqDict):
@@ -21,6 +21,13 @@ def json2prop(_json):
     _dic=json.loads(_json)
     return namedtuple('X', _dic.keys())(*_dic.values())
 
+def d2p(_dic):
+    return namedtuple('X', _dic.keys())(*_dic.values())
+
+def json2dict(_json):
+    _dic=json.loads(_json)
+    return namedtuple('X', _dic.keys())(*_dic.values())
+
 def jsonfile2prop(__jsonfile):
     _jsonfile=pathlib.Path(__jsonfile).resolve()
     #_jsonfile= os.path.abspath(__jsonfile)
@@ -29,6 +36,10 @@ def jsonfile2prop(__jsonfile):
       d=f.read()
       return json.loads(d)
 
+def jsonfile2dict(__jsonfile):
+    _dic=jsonfile2prop(__jsonfile)
+    return namedtuple('X', _dic.keys())(*_dic.values())
+
 def json_DecodeHierarchy(_dicParentJSON,_targetProp):
 	_dicParent=json.loads(_dicParentJSON)
 	_dic=_dicParent[_targetProp]
